@@ -6,7 +6,7 @@ use 5.016;
 use warnings;
 use utf8;
 
-our $VERSION = 1.002;
+our $VERSION = 1.003;
 
 use parent qw(Alien::Base);
 
@@ -21,7 +21,7 @@ Alien::libmaxminddb - Find or download and install libmaxminddb
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 SYNOPSIS
 
@@ -66,12 +66,13 @@ None.
 
 =head1 DEPENDENCIES
 
-Requires L<Alien::Build> from CPAN.  On Windows, L<Alien::MSYS> needs to be
-installed.
+Requires L<Alien::Build> from CPAN.
 
 Install the package C<libmaxminddb-devel> or C<libmaxminddb-dev> if you would
 like to use your operating system's libmaxminddb library.
 
+Windows is not supported.  Please do not ask for Windows support.
+
 =head1 INCOMPATIBILITIES
 
 None.
